diff --git a/README.md b/README.md
index 9609bf8..c7f1143 100644
--- a/README.md
+++ b/README.md
@@ -1,33 +1,23 @@
-```
-__/\\\\\\\\\\\\\\\___/\\\\\\\\\\\___/\\\\\\\\\\\\\\\___/\\\\\\\\\\\\\\\_
- _\/\\\///////////___\/////\\\///___\/\\\///////////___\/\\\///////////__
- _\/\\\__________________\/\\\______\/\\\______________\/\\\_____________
- _\/\\\\\\\\\\\__________\/\\\______\/\\\\\\\\\\\______\/\\\\\\\\\\\_____
- _\/\\\///////___________\/\\\______\/\\\///////_______\/\\\///////______
- _\/\\\__________________\/\\\______\/\\\______________\/\\\_____________
- _\/\\\__________________\/\\\______\/\\\______________\/\\\_____________
- _\/\\\_______________/\\\\\\\\\\\__\/\\\______________\/\\\\\\\\\\\\\\\_
- _\///_______________\///////////___\///_______________\///////////////__
-```
-
+# Fifengine Python Tutorials  
-Welcome to the FIFE tutorials package. Please find the following tutorials in
-this package:
+Welcome to the FIFE tutorials package.
+
+Please find the following tutorials in this package:
* [1a] - Initializing FIFE
* [1b] - Loading and displaying a map
* [1c] - Interacting with the map
* [1d] - Adding a simple dialog box
-All source code has quite detailed comments. Each tutorial builds on the
-previous ones. Begin by looking at the `run.py` files in their respective
-directories. That is the base starting point.
+- the source code has detailed comments
+- each tutorial builds on the previous one
+- the `run.py` file is the starting point
To run these tutorials drop to a command prompt and change directory to the
tutorial directory you are working in and type: `python run.py`
-[1a]: tutorial1a/run.py
-[1b]: tutorial1b/run.py
-[1c]: tutorial1c/run.py
-[1d]: tutorial1d/run.py
+[1a]: tutorial1a/
+[1b]: tutorial1b/
+[1c]: tutorial1c/
+[1d]: tutorial1d/
diff --git a/assets/maps/tutorial1map.xml b/assets/maps/tutorial1map.xml
index 7aad7f4..fe72421 100644
--- a/assets/maps/tutorial1map.xml
+++ b/assets/maps/tutorial1map.xml
@@ -165,6 +165,6 @@
-
+
diff --git a/assets/objects/actors/player/skel/object.xml b/assets/objects/actors/player/skel/object.xml
index ea9c13f..b50110e 100644
--- a/assets/objects/actors/player/skel/object.xml
+++ b/assets/objects/actors/player/skel/object.xml
@@ -1,27 +1,29 @@
-
+
+
+
\ No newline at end of file
diff --git a/assets/objects/ground/grass/01/object.xml b/assets/objects/ground/grass/01/object.xml
index 91b0216..a3fd358 100644
--- a/assets/objects/ground/grass/01/object.xml
+++ b/assets/objects/ground/grass/01/object.xml
@@ -1,7 +1,9 @@
-
+
+
+
diff --git a/tutorial1a/run.py b/tutorial1a/run.py
index 5648c7f..833273e 100644
--- a/tutorial1a/run.py
+++ b/tutorial1a/run.py
@@ -38,8 +38,7 @@
# a settings-dist.xml file a blank settings file will be created for you by
# the Setting extension.
settings = Setting(app_name="tutorial1",
- settings_file="./settings.xml",
- settings_gui_xml="")
+ settings_file="./settings.xml")
def main():
# This creates an instance of Tutorial1Application and passes it the
diff --git a/tutorial1a/settings-dist.xml b/tutorial1a/settings-dist.xml
index 2295685..1db0921 100644
--- a/tutorial1a/settings-dist.xml
+++ b/tutorial1a/settings-dist.xml
@@ -26,8 +26,8 @@
all 1
- 1
- 0
+ True
+ False False
diff --git a/tutorial1b/run.py b/tutorial1b/run.py
index 5648c7f..833273e 100644
--- a/tutorial1b/run.py
+++ b/tutorial1b/run.py
@@ -38,8 +38,7 @@
# a settings-dist.xml file a blank settings file will be created for you by
# the Setting extension.
settings = Setting(app_name="tutorial1",
- settings_file="./settings.xml",
- settings_gui_xml="")
+ settings_file="./settings.xml")
def main():
# This creates an instance of Tutorial1Application and passes it the
diff --git a/tutorial1b/settings-dist.xml b/tutorial1b/settings-dist.xml
index 2295685..1db0921 100644
--- a/tutorial1b/settings-dist.xml
+++ b/tutorial1b/settings-dist.xml
@@ -26,8 +26,8 @@
all 1
- 1
- 0
+ True
+ False False
diff --git a/tutorial1c/run.py b/tutorial1c/run.py
index 5648c7f..833273e 100644
--- a/tutorial1c/run.py
+++ b/tutorial1c/run.py
@@ -38,8 +38,7 @@
# a settings-dist.xml file a blank settings file will be created for you by
# the Setting extension.
settings = Setting(app_name="tutorial1",
- settings_file="./settings.xml",
- settings_gui_xml="")
+ settings_file="./settings.xml")
def main():
# This creates an instance of Tutorial1Application and passes it the
diff --git a/tutorial1c/settings-dist.xml b/tutorial1c/settings-dist.xml
index 2295685..1db0921 100644
--- a/tutorial1c/settings-dist.xml
+++ b/tutorial1c/settings-dist.xml
@@ -26,8 +26,8 @@
all 1
- 1
- 0
+ True
+ False False
diff --git a/tutorial1d/settings-dist.xml b/tutorial1d/settings-dist.xml
index 2295685..1db0921 100644
--- a/tutorial1d/settings-dist.xml
+++ b/tutorial1d/settings-dist.xml
@@ -26,8 +26,8 @@
all 1
- 1
- 0
+ True
+ False False
diff --git a/tutorial1d/scripts/tutorial1.py b/tutorial1d/scripts/tutorial1.py
index 2f9d76a..59dc58d 100644
--- a/tutorial1d/scripts/tutorial1.py
+++ b/tutorial1d/scripts/tutorial1.py
@@ -29,10 +29,12 @@
from fife.extensions import pychan
# Import the ApplicationBase. This is where a lot of magic happens but
# you don't need to know the inner workings just yet. Once you are more
-# familiar with FIFE you'll understand ApplicationBase much more.
-from fife.extensions.basicapplication import ApplicationBase
+# familiar with FIFE you'll understand PychanApplicationBase much more.
+# PychanApplicationBase extends ApplicationBase and adds the proper code to
+# initialize pychan for GUI support.
+from fife.extensions.pychan import pychanbasicapplication
class QueryDialog(object):
"""
@@ -54,12 +56,12 @@ def __init__(self, acceptedfunction, title, text):
# then sets that widgets text property. Easy isn't it?
# This is the title of our dialog box.
self._queryname = self._widget.findChild(name="queryname")
- self._queryname.text = unicode(title)
+ self._queryname.text = str(title, 'utf-8')
# This searches for a child widget with the name "querytext" and
# then sets that widgets text property. Easy isn't it?
self._querytext = self._widget.findChild(name="querytext")
- self._querytext.text = unicode(text)
+ self._querytext.text = str(text, 'utf-8')
# Pychan has some handy functions to bind callbacks to certain widget
# events. In this case when the the 'accept' and 'decline' child
@@ -141,9 +143,10 @@ def mouseWheelMovedDown(self, event):
def mouseDragged(self, event):
pass
-class Tutorial1Application(ApplicationBase):
+class Tutorial1Application(pychanbasicapplication.PychanApplicationBase):
"""
- The main application. It inherits fife.extensions.ApplicationBase
+ The main application. It inherits
+ fife.extensions.pychan.pychanbasicapplication.PychanApplicationBase
and implements the _pump() function which gets called every frame.
"""
def __init__(self, settings):
@@ -29,10 +29,12 @@
from fife.extensions import pychan
-# Import the ApplicationBase. This is where a lot of magic happens but
+# Import the PychanApplicationBase. This is where a lot of magic happens but
# you don't need to know the inner workings just yet. Once you are more